@@ -128,8 +128,12 @@ sub check_href {
 		$options -> {href} .= "\&sid=$_REQUEST{sid}";
 	}	
 	
+	if ($options -> {href} !~ /^(\#|java|\/i\/)/ and $_REQUEST {select} and $options -> {href} !~ /[\&\?]select=/) {
+		$options -> {href} .= "\&select=$_REQUEST{select}";
+	}	
+
 	if ($options -> {href} !~ /^(\#|java|\/i\/)/) {	
-		$options -> {href} =~ s/[\&\?]_?salt=[\d\.]+//g;
+		$options -> {href} =~ s/([\&\?])_?salt=[\d\.]+/$1/g;
 		$options -> {href} .= '&salt=' . (rand * time);
 	}	
 
@@ -144,12 +148,16 @@ sub check_href {
 	if ($_FLAG_ADD_LAST_QUERY_STRING && $conf -> {core_auto_esc} && $options -> {href} !~ /^(\#|java|\/i\/)/) {
 	
 		my $query_string = $ENV {QUERY_STRING};
-		$query_string =~ s{\&?__scrollable_table_row=\d*}{}g;
+		$query_string =~ s{\&?__last_query_string\=[^\&]+}{}gsm;
+
+		$query_string =~ s{\&?__scrollable_table_row\=\d*}{}g;
 		$query_string .= "&__scrollable_table_row=$scrollable_row_id";
 		
 		my $esc_query_string = MIME::Base64::encode ($query_string);
 		$esc_query_string =~ y{+/=}{-_.};
+		$esc_query_string =~ s{[\r\n]}{}gsm;
 	
+		$options -> {href} =~ s{\&?__last_query_string\=[^\&]+}{}gsm;
 		$options -> {href} .= "&__last_query_string=$esc_query_string";
 		
 	}		
